==> jc-1.4.0.tar.gz: java/util/EmptyStackException.h <==
// public class java.util.EmptyStackException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 978e8391b640fd70 java_util_EmptyStackException

// header file dependencies
// @dep_header java_lang_RuntimeException

#include "java/lang/RuntimeException.h"

#ifndef _JC_java_util_EmptyStackException_H_
#define _JC_java_util_EmptyStackException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_util_EmptyStackException$sub_refs	_jc_java_util_EmptyStackException$sub_refs;
typedef struct _jc_java_util_EmptyStackException$sub_nonrefs	_jc_java_util_EmptyStackException$sub_nonrefs;
typedef struct _jc_java_util_EmptyStackException$refs	_jc_java_util_EmptyStackException$refs;
typedef struct _jc_java_util_EmptyStackException$nonrefs	_jc_java_util_EmptyStackException$nonrefs;
typedef struct _jc_java_util_EmptyStackException$object	_jc_java_util_EmptyStackException$object;

typedef struct _jc_java_util_EmptyStackException$fields_struct	_jc_java_util_EmptyStackException$fields_struct;
typedef const struct _jc_java_util_EmptyStackException$vmethods	_jc_java_util_EmptyStackException$vmethods;
typedef const struct _jc_java_util_EmptyStackException$vtable	_jc_java_util_EmptyStackException$vtable;
typedef const struct _jc_java_util_EmptyStackException$vtype	_jc_java_util_EmptyStackException$vtype;

// Class fields structure
struct _jc_java_util_EmptyStackException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_util_EmptyStackException$fields_struct _jc_java_util_EmptyStackException$class_fields;

// Constructors
extern void _jc_java_util_EmptyStackException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_util_EmptyStackException$object *);

// Virtual methods structure
struct _jc_java_util_EmptyStackException$vmethods {
};

// Vtable
struct _jc_java_util_EmptyStackException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_java_util_EmptyStackException$vmethods	java_util_EmptyStackException;
};

// Vtype
struct _jc_java_util_EmptyStackException$vtype {
	_jc_type			type;
	_jc_java_util_EmptyStackException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_EmptyStackException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_util_EmptyStackException$refs {
    _jc_java_util_EmptyStackException$sub_refs	java_util_EmptyStackException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_EmptyStackException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_EmptyStackException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_java_util_EmptyStackException$sub_nonrefs	java_util_EmptyStackException;
};

// Object instance structure
struct _jc_java_util_EmptyStackException$object {
	_jc_java_util_EmptyStackException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_EmptyStackException$vtype	*vtype;
	_jc_java_util_EmptyStackException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_EmptyStackException$vtype _jc_java_util_EmptyStackException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_EmptyStackException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_EmptyStackException$class_object;

#endif	/* _JC_java_util_EmptyStackException_H_ */

==> jc-1.4.6.tar.gz: java/util/EmptyStackException.h <==
// public class java.util.EmptyStackException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 978e8391b640fd70 java_util_EmptyStackException

// header file dependencies
// @dep_header java_lang_RuntimeException

#include "java/lang/RuntimeException.h"

#ifndef _JC_java_util_EmptyStackException_H_
#define _JC_java_util_EmptyStackException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_util_EmptyStackException$sub_refs	_jc_java_util_EmptyStackException$sub_refs;
typedef struct _jc_java_util_EmptyStackException$sub_nonrefs	_jc_java_util_EmptyStackException$sub_nonrefs;
typedef struct _jc_java_util_EmptyStackException$refs	_jc_java_util_EmptyStackException$refs;
typedef struct _jc_java_util_EmptyStackException$nonrefs	_jc_java_util_EmptyStackException$nonrefs;
typedef struct _jc_java_util_EmptyStackException$object	_jc_java_util_EmptyStackException$object;

typedef struct _jc_java_util_EmptyStackException$fields_struct	_jc_java_util_EmptyStackException$fields_struct;
typedef const struct _jc_java_util_EmptyStackException$vmethods	_jc_java_util_EmptyStackException$vmethods;
typedef const struct _jc_java_util_EmptyStackException$vtable	_jc_java_util_EmptyStackException$vtable;
typedef const struct _jc_java_util_EmptyStackException$vtype	_jc_java_util_EmptyStackException$vtype;

// Class fields structure
struct _jc_java_util_EmptyStackException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_util_EmptyStackException$fields_struct _jc_java_util_EmptyStackException$class_fields;

// Constructors
extern void _jc_java_util_EmptyStackException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_util_EmptyStackException$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_util_EmptyStackException$vmethods {
};

// Vtable
struct _jc_java_util_EmptyStackException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_java_util_EmptyStackException$vmethods	java_util_EmptyStackException;
};

// Vtype
struct _jc_java_util_EmptyStackException$vtype {
	_jc_type			type;
	_jc_java_util_EmptyStackException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_EmptyStackException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_util_EmptyStackException$refs {
    _jc_java_util_EmptyStackException$sub_refs	java_util_EmptyStackException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_EmptyStackException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_EmptyStackException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_java_util_EmptyStackException$sub_nonrefs	java_util_EmptyStackException;
};

// Object instance structure
struct _jc_java_util_EmptyStackException$object {
	_jc_java_util_EmptyStackException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_EmptyStackException$vtype	*vtype;
	_jc_java_util_EmptyStackException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_EmptyStackException$vtype _jc_java_util_EmptyStackException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_EmptyStackException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_EmptyStackException$class_object;

#endif	/* _JC_java_util_EmptyStackException_H_ */
